@@ -15,13 +15,12 @@ class BudgetDialog : public QDialog
                      Qt::WindowFlags f = 0);
 
  signals:
-        void changeBudget(double budget, bool setDefault);
+        void changeBudget(double budget);
 
  private slots:
         void changeBudget();
 
  private:
         QLineEdit *_budget;
-        QCheckBox *_default;
 };
 #endif
