@@ -11,6 +11,7 @@
 #include "dbmanager.h"
 #include "concept.h"
 #include "summarywindow.h"
+#include "account.h"
 
 class Controller : public QObject
 {
@@ -25,6 +26,14 @@ class Controller : public QObject
         void previousMonth();
         void nextMonth();
 
+        void newAccountSelected();
+        void newAccountConfirmed(Account *a);
+        void accountsSelected();
+        void accountDetailsSelected(QModelIndex index);
+        void deleteAccountConfirmed(Account *a);
+        void updateAccountConfirmed(Account *a);
+        void selectAccountConfirmed(Account *a);
+
         void newExpenseSelected();
         void newExpenseConfirmed(Expense *e);
         void expensesSelected();
@@ -33,7 +42,7 @@ class Controller : public QObject
         void updateExpenseConfirmed(Expense *e);
 
         void budgetSelected();
-        void changeBudgetConfirmed(double budget, bool setDefault);
+        void changeBudgetConfirmed(double budget);
 
         void conceptsSelected();
         void newConceptSelected();
@@ -56,6 +65,7 @@ class Controller : public QObject
         void loadMonth(bool reload = false);
         void loadConcepts();
         void loadScheduled();
+        void loadAccounts();
 
         MonthData *month;
         QDate date;
@@ -63,8 +73,10 @@ class Controller : public QObject
         DBManager db;
         QStandardItemModel *concepts;
         QStandardItemModel *scheduled;
+        QStandardItemModel *accounts;
         QSettings *settings;
         SummaryWindow *summaryWindow;
+        Account *activeAccount;
 };
 
 #endif
